==> geopsypack-src-3.3.5.tar.gz: geopsypack-src-3.3.5/ArrayCore/src/SPACResults.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-04-13
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef SPACRESULTS_H
#define SPACRESULTS_H

#include "AbstractArrayResults.h"
#include "SPACParameters.h"
#include "SPACStatistics.h"
#include "ArrayCoreDLLExport.h"

namespace ArrayCore {

  class ARRAYCORE_EXPORT SPACResults : public AbstractArrayResults
  {
  public:
    SPACResults();
    virtual ~SPACResults();

    virtual void setArray(const ArraySelection * array);

    void setParameters(const SPACParameters& param);
    virtual void clear();

    void addValue(int frequencyIndex, int ring, int component, double val);
    void addRejected(int frequency, int * rejected);

    void commitStatistics();
    void save(QString fileName);
    void reportRejects();
  private:
    Mutex _addLock;
    int _nFrequencies, _nRings, _nComponents;
    AutocorrCurves * _target;
    SPACStatistics * _stats;
    int * _rejected[3];
  };

} // namespace ArrayCore

#endif // SPACRESULTS_H

==> geopsypack-src-3.4.1.tar.gz: geopsypack-src-3.4.1/ArrayCore/src/SPACResults.h <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2018-04-13
**  Copyright: 2018-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef SPACRESULTS_H
#define SPACRESULTS_H

#include "AbstractArrayResults.h"
#include "SPACParameters.h"
#include "SPACStatistics.h"
#include "ArrayCoreDLLExport.h"

namespace ArrayCore {

  class SPACPeaks;

  class ARRAYCORE_EXPORT SPACResults : public AbstractArrayResults
  {
  public:
    SPACResults();
    virtual ~SPACResults();

    struct ValueInfo
    {
      DateTime time;
      int frequencyIndex;
      double frequency;
    };

    const SPACParameters * parameters() const {return static_cast<const SPACParameters *>(_parameters);}

    virtual void setArray(const ArraySelection * array);

    void setParameters(const SPACParameters& param);
    virtual void clear();

    void addValue(Mode::Polarization polarization, const ValueInfo& info,
                  int ring, double value);
    void addRejected(int frequency, int * rejected);

    void commitStatistics();
    void save(QString fileName, const QString& log);
    void reportRejects();
  private:
    Mutex _addLock;
    int _nFrequencies, _nRings, _nComponents;
    AutocorrCurves * _target;
    SPACStatistics * _stats;
    int * _rejected[3];
    SPACPeaks * _peaks;
  };

} // namespace ArrayCore

#endif // SPACRESULTS_H
